## Alpaca
![alpaca_logo](examples/alpaca.png)

Package for active learning and uncertainty quantification in neural nets.

Example experiment script/notebooks with library usage are in `examples` folder.
